##  Dashboards
At this time there aren't specific settings within the Authorization model that determine access to Dashboards. However, when users create Dashboards, they can define some access settings for the particular Dashboard that they are creating. For more information on dashboards, see [Dashboard Modeling](https://help.sap.com/docs/leanix/ea/dashboard-modeling?locale=en-US&state=PRODUCTION&version=CLOUD "Best practices and examples for creating dashboards tailored to various use cases.").
**Note**
At this time, all roles are able to create Public Dashboards even those with the role of VIEWER.
